******************************************************
*  Program...........: Samples.prg
*  Author............: Lauren Clarke
*  Project...........: Parsing Power Tools
*  Created...........: 04/10/2004
*  Copyright.........:
*  Description.......: Code samples for "Parsing Power Tools"
*  Unit Test.........: None
*  Dependencies......: VFP8, RELATION
*  Assumptions.......: SET EXACT OFF
*  Last Change.......: 04/10/2004
*  Change Log........: See end of file
******************************************************
* COMMENTS
*
* Code samples for "Parsing Power Tools Part 1" by Lauren Clarke and Randy Pearson
* search for the code by Code Listing Number.
* Samples have been gathered into functions for easy calling.
*

* Comment/Uncomment the lines below and execute this prg to see each secton's code samples
CLEAR
=PartOneSamples()


***********************************************************************************************
** PART ONE SAMPLES
***********************************************************************************************

FUNCTION PartOneSamples()

  ? [==== Results: Code Listing 1 ====]
  lcList =  [205.180.85.40;205.140.111.203;206.63.99.226;]+;
    [206.63.99.227;206.63.99.228]
  lnEndPos   = 0
  lnStartPos = 0
  FOR lnK = 1 TO OCCURS([;], lcList) + 1
    lnEndPos = AT( [;], lcList, lnK )
    lnEndPos = IIF( lnEndPos = 0, LEN( lcList ) + 1, lnEndPos )
    lcIP     = SUBSTR( lcList, lnStartPos+1, lnEndPos-lnStartPos-1 )
    ? lcIP   && <= print the IP
    lnStartPos = AT( [;], lcList, lnK )
  ENDFOR


  ? [==== Results: Code Listing 2 ====]

  lcList =  [205.180.85.40;205.140.111.203;206.63.99.226;]+;
    [206.63.99.227;206.63.99.228]

  ALINES(laIPs, lcList, .T., [;] )

  FOR EACH lcIP IN laIPs
    ? m.lcIP
  ENDFOR

  ? [==== Results: Code Listing 3 ====]
  lcList =  [205.180.85.40;205.140.111.203;206.63.99.226;]+;
    [206.63.99.227;206.63.99.228]
  FOR lnK = 1 TO GETWORDCOUNT( lcList, [;] )
    ? GETWORDNUM( lcList, lnK, [;] )
  ENDFOR

  ? [==== Results: Code Listing 4 ====]
  lcList = [205.180.85.40,205.140.111.203;206.63.99.226;206.63.99.227;206.63.99.228;192.168.0.1]
  FOR lnK = 1 TO GETWORDCOUNT( lcList, [;,] )
    ? GETWORDNUM( lcList, lnK, [;,] )
  ENDFOR

  ? [==== Results: Code Listing 5 ====]
*-- normally, we'd extract the colorscheme string from the ini
*   with an API call or another parsing routine
  lcColorscheme=[background,red|foreground,blue|fontcolor,green]

*-- extract the color scheme data from the .ini into an object
  loCScheme = CREATEOBJECT("empty")
  FOR lnK = 1 TO GETWORDCOUNT( lcColorscheme, [|] )
    lcPropValue = GETWORDNUM( lcColorscheme, lnK , [|] )
    lcProperty = GETWORDNUM( lcPropValue,1,[,] )
    lcValue = GETWORDNUM( lcPropValue,2,[,] )
    ADDPROPERTY( loCScheme,lcProperty,lcValue )
  ENDFOR

  WITH loCScheme
    ? .background  && prints "red"
    ? .foreground  && prints "blue"
    ? .fontcolor   && prints "green"
  ENDWITH

  ? [==== Results: Code Listing 6 ====]
  
  *-- see below for UDF
  ? DecimalPlaces(1234.5678)   && prints 4
  ? DecimalPlaces($1234.5678)  && prints 4
  ? DecimalPlaces("1234.5678") && prints 4


  ? [==== Results: Code Listing 7 ====]
TEXT to lcText textmerge noshow pretext 3
    This is a test,
    note how the initial spaces are trimmed
    this is due to the pretext 1 directive above.
    Today is: <<date()>>
ENDTEXT


  ? lcText


  lcText = [The date is <<date()>>]
  ? TEXTMERGE( lcText )
*-- calls to textmerge can be nested
  lcText2 = [The time is <<time()>>, and <<textmerge(lcText)>>]
  ? TEXTMERGE( lcText2 )
*-- or, can be recursed internally
  lcText2 = [The time is <<time()>>, and <<lcText>>]
  ? TEXTMERGE( lcText2 , .T. )


ENDFUNC


*-----------------------------------------------------*
FUNCTION inListString( tcItem, tcList, tcDelimiter, tltrim )

  LOCAL lcTrimmedList
  tcDelimiter = IIF( VARTYPE( m.tcDelimiter ) # [C], [,] , m.tcDelimiter )

  IF m.tltrim
    tcItem = ALLTRIM( m.tcItem )
*-- strip all leading and trailing spaces from list
    lcTrimmedList = []
    FOR lnK = 1 TO GETWORDCOUNT( m.tcList, m.tcDelimiter )
      lcTrimmedList = m.lcTrimmedList + GETWORDNUM( m.tcList, m.lnK, m.tcDelimiter+[ ] )+m.tcDelimiter
    ENDFOR
    m.tcList = m.lcTrimmedList
  ENDIF

  tcItem = m.tcDelimiter + m.tcItem + m.tcDelimiter
  tcList = m.tcDelimiter + m.tcList + m.tcDelimiter

  RETURN m.tcItem $ m.tcList
ENDFUNC



*-----------------------------------------------------*
FUNCTION decimalPlaces( tnValue ) AS INTEGER
* returns the number of decimal places present in tnValue
  LOCAL lnSetPoint, lnRetVal, lcStringVal
  lcStringVal = PADR( tnValue, 40 )   && max 18 either side of .
  lnRetVal    = 0
  lnSetPoint  = AT( SET("point"), m.lcStringVal )
  IF lnSetPoint > 0
    lnRetVal = LEN( RTRIM( m.lcStringVal ) ) - m.lnSetPoint
  ENDIF
  RETURN m.lnRetVal
ENDFUNC

